summaryrefslogtreecommitdiffstats
path: root/tdeui/keditlistbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/keditlistbox.h')
-rw-r--r--tdeui/keditlistbox.h43
1 files changed, 38 insertions, 5 deletions
diff --git a/tdeui/keditlistbox.h b/tdeui/keditlistbox.h
index 4a00b0cb7..c6930128b 100644
--- a/tdeui/keditlistbox.h
+++ b/tdeui/keditlistbox.h
@@ -33,7 +33,7 @@ class KEditListBoxPrivate;
/**
* An editable listbox
*
- * This class provides a editable listbox ;-), this means
+ * This class provides an editable listbox ;-), this means
* a listbox which is accompanied by a line edit to enter new
* items into the listbox and pushbuttons to add and remove
* items from the listbox and two buttons to move items up and down.
@@ -199,25 +199,58 @@ public:
void changed();
/**
* This signal is emitted when the user adds a new string to the list,
* the parameter is the added string.
* @since 3.2
+ * @see added( int item, const TQString & text )
*/
void added( const TQString & text );
/**
- * This signal is emitted when the user removes a string from the list,
- * the parameter is the removed string.
+ * This signal is emitted when the user adds a new string to the list.
+ * @param item is the added item's position in the list.
+ * @param text is the added string.
+ * @since R14.1.0
+ * @see added( const TQString & text )
+ */
+ void added( int item, const TQString & text );
+
+ /**
+ * This signal is emitted when the user removes a string from the list.
+ * @param text is the removed string.
* @since 3.2
+ * @see removed( int item, const TQString & text )
*/
void removed( const TQString & text );
/**
+ * This signal is emitted when the user removes a string from the list.
+ * @param item is the removed item's position in the list.
+ * @param text is the removed string.
+ * @since R14.1.0
+ * @see removed( const TQString & text )
+ */
+ void removed( int item, const TQString & text );
+
+ /**
* This signal is emitted when the user renames a list item.
+ * @param from is the original item's text.
+ * @param to is the new text of the item.
* @since R14.1.0
+ * @see renamed( int item, const TQString &from, const TQString &to )
*/
void renamed( const TQString &from, const TQString &to );
+ /**
+ * This signal is emitted when the user renames a list item.
+ * @param item is the renamed item's position in the list.
+ * @param from is the original item's text.
+ * @param to is the new text of the item.
+ * @since R14.1.0
+ * @see renamed( const TQString &from, const TQString &to )
+ */
+ void renamed( int item, const TQString &from, const TQString &to );
+
protected slots:
//the names should be self-explaining
void moveItemUp();
@@ -199,25 +199,58 @@ public:
void changed();
/**
- * This signal is emitted when the user adds a new string to the list,
- * the parameter is the added string.
+ * This signal is emitted when the user adds a new string to the list.
+ * @param text is the added string.
* @since 3.2